import {Component, ViewChild, AfterViewInit} from "@angular/core";
import {DayPilot, DayPilotSchedulerComponent} from "daypilot-pro-angular";
import {DataService} from "./data.service";{}

@Component({
  selector: 'scheduler-component',
  template: `<daypilot-scheduler [config]="config" [events]="events" #scheduler></daypilot-scheduler>`,
  styles: [``]
})
export class SchedulerComponent implements AfterViewInit {

  @ViewChild("scheduler")
  scheduler!: DayPilotSchedulerComponent;

  events: DayPilot.EventData[] = [];

  config: DayPilot.SchedulerConfig = {
    timeHeaders: [{"groupBy":"Month"},{"groupBy":"Day","format":"d"}],
    scale: "Day",
    days: 31,
    startDate: "2021-07-01",
    treeEnabled: true,
    separators: [
      {color: "red", location: DayPilot.Date.today() }
    ],
    onTimeRangeSelected: async (args) => {
      const dp = args.control;
      const modal = await DayPilot.Modal.prompt("Create a new event:", "Event 1");
      dp.clearSelection();
      if (!modal.result) { return; }
      dp.events.add({
        start: args.start,
        end: args.end,
        id: DayPilot.guid(),
        resource: args.resource,
        text: modal.result
      });

    },
    contextMenu: new DayPilot.Menu({
      items: [
        { text: "Delete", onClick: (args) => { this.scheduler.control.events.remove(args.source); } },
        { text: "-"},
        {
          text: "Blue",
          icon: "icon icon-blue",
          tags: { color: "#1155cc" },
          onClick: args => { this.updateColor(args.source, args.item.tags.color); }
        },
        {
          text: "Green",
          icon: "icon icon-green",
          tags: { color: "#6aa84f" },
          onClick: args => { this.updateColor(args.source, args.item.tags.color); }
        },
        {
          text: "Yellow",
          icon: "icon icon-yellow",
          tags: { color: "#f1c232" },
          onClick: args => { this.updateColor(args.source, args.item.tags.color); }
        },
        {
          text: "Red",
          icon: "icon icon-red",
          tags: { color: "#cc0000" },
          onClick: args => { this.updateColor(args.source, args.item.tags.color); }
        },
      ],
      onShow: args => {
        let e = args.source;

        // disable deleting for events that start in the past
        if (e.start() < DayPilot.Date.today()) {
          args.menu.items[0].disabled = true;
        }
        else {
          args.menu.items[0].disabled = false;
        }
      }
    }),
    contextMenuResource: new DayPilot.Menu({
      onShow: args => {
        let hasChildren = args.source.children().length > 0;
        if (hasChildren) {
          args.menu.items = this.menuItemsGroup;
        }
        else {
          args.menu.items = this.menuItemsResource;
        }
      }
    })
  };

  menuItemsGroup: any[] = [
    { text: "Group Details"}
  ];

  menuItemsResource: any[] = [
    { text: "Resource Details"}
  ];

  constructor(private ds: DataService) {
  }

  ngAfterViewInit(): void {
    this.ds.getResources().subscribe(result => this.config.resources = result);

    const from = this.scheduler.control.visibleStart();
    const to = this.scheduler.control.visibleEnd();
    this.ds.getEvents(from, to).subscribe(result => {
      this.events = result;
    });
  }

  updateColor(e: DayPilot.Event, color: string): void {
    e.data.barColor = color;
    this.scheduler.control.events.update(e);
  }

}

